##  Step 3: Generate a Software Bill of Materials (SBOM)
SBOM files provide a comprehensive inventory of all software components, libraries, and modules used by microservices. They help ensure license compliance, identify potential security risks, and offer a deeper understanding of your software supply chain. For more information, see [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.").
SAP LeanIX does not offer capabilities for automatic SBOM generation. For more information on SBOM requirements and generation methods, see [Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the requirements for SBOM files and get an overview of the methods for generating them.").
